@@ -68,10 +68,10 @@ class TestContainer(IntegrationTestCase):
         super(TestContainer, self).tearDown()
         self.delete_container(self.container.name)
 
-    def test_update(self):
+    def test_save(self):
         """The container is updated to a new config."""
         self.container.config['limits.cpu'] = '1'
-        self.container.update(wait=True)
+        self.container.save(wait=True)
 
         self.assertEqual('1', self.container.config['limits.cpu'])
         container = self.client.containers.get(self.container.name)
@@ -91,7 +91,7 @@ class TestContainer(IntegrationTestCase):
         self.container.delete(wait=True)
 
         self.assertRaises(
-            exceptions.NotFound,
+            exceptions.LXDAPIException,
             self.client.containers.get, self.container.name)
 
     def test_start_stop(self):
@@ -152,3 +152,11 @@ class TestContainer(IntegrationTestCase):
         stdout, stderr = self.container.execute(['echo', 'test'])
 
         self.assertEqual('test\n', stdout)
+
+    def test_publish(self):
+        """A container is published."""
+        image = self.container.publish(wait=True)
+
+        self.assertIn(
+            image.fingerprint,
+            [i.fingerprint for i in self.client.images.all()])
