@@ -53,7 +53,8 @@ class _APINode(object):
             '{}/{}'.format(self._api_endpoint, item),
             cert=self.session.cert, verify=self.session.verify)
 
-    def _assert_response(self, response, allowed_status_codes=(200,)):
+    def _assert_response(
+            self, response, allowed_status_codes=(200,), stream=False):
         """Assert properties of the response.
 
         LXD's API clearly defines specific responses. If the API
@@ -65,6 +66,11 @@ class _APINode(object):
         if response.status_code not in allowed_status_codes:
             raise exceptions.LXDAPIException(response)
 
+        # In the case of streaming, we can't validate the json the way we
+        # would with normal HTTP responses, so just ignore that entirely.
+        if stream:
+            return
+
         try:
             data = response.json()
         except ValueError:
@@ -80,10 +86,19 @@ class _APINode(object):
                 # Missing 'type' in response
                 raise exceptions.LXDAPIException(response)
 
+    @property
+    def scheme(self):
+        return parse.urlparse(self.api._api_endpoint).scheme
+
+    @property
+    def netloc(self):
+        return parse.urlparse(self.api._api_endpoint).netloc
+
     def get(self, *args, **kwargs):
         """Perform an HTTP GET."""
-        response = self.session.get(self._api_endpoint, *args, **kwargs)
-        self._assert_response(response)
+        response = self.session.get(
+            self._api_endpoint, *args, **kwargs)
+        self._assert_response(response, stream=kwargs.get('stream', False))
         return response
 
     def post(self, *args, **kwargs):
@@ -218,16 +233,15 @@ class Client(object):
 
     @property
     def websocket_url(self):
-        parsed = parse.urlparse(self.api._api_endpoint)
-        if parsed.scheme in ('http', 'https'):
-            host = parsed.netloc
-            if parsed.scheme == 'http':
+        if self.api.scheme in ('http', 'https'):
+            host = self.api.netloc
+            if self.api.scheme == 'http':
                 scheme = 'ws'
             else:
                 scheme = 'wss'
         else:
             scheme = 'ws+unix'
-            host = parse.unquote(parsed.netloc)
+            host = parse.unquote(self.api.netloc)
         url = parse.urlunparse((scheme, host, '', '', '', ''))
         return url
 
