@@ -185,7 +185,6 @@ RULES = [
                 },
                 'created_at': "1983-06-16T00:00:00-00:00",
                 'last_used_at': "1983-06-16T00:00:00-00:00",
-                'description': "Some description",
                 'devices': {
                     'root': {
                         'path': "/",
@@ -213,10 +212,7 @@ RULES = [
                 ],
                 'stateful': False,
                 'status': "Running",
-                'status_code': 103,
-                'unsupportedbypylxd': ("This attribute is not supported by "
-                                       "pylxd. We want to test whether the "
-                                       "mere presence of it makes it crash.")
+                'status_code': 103
             }},
         'method': 'GET',
         'url': r'^http://pylxd.test/1.0/containers/an-container$',
@@ -452,7 +448,7 @@ RULES = [
         'url': r'^http://pylxd.test/1.0/images/e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855$',  # NOQA
     },
     {
-        'text': '',
+        'text': '0' * 2048,
         'method': 'GET',
         'url': r'^http://pylxd.test/1.0/images/e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855/export$',  # NOQA
     },
